# frozen_string_literal: true

# Copyright 2019 Richard Davis
#
# This file is part of glsnip.
#
# glsnip is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# glsnip is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with glsnip.  If not, see <http://www.gnu.org/licenses/>.

require 'colorize'

module Glsnip
  ##
  # = Formatter
  # Author::    Richard Davis
  # Copyright:: Copyright 2019 Richard Davis
  # License::   GNU Public License 3
  #
  # Formats execution results and prints to the terminal
  class Formatter
    def self.error(body)
      "Failure: #{body['message']}".colorize(:red)
    end

    def self.list(body)
      snippets = []
      body.each do |snippet|
        snippets.push "\"#{snippet['title']}\" (#{snippet['file_name']} | #{snippet['id']}): #{snippet['web_url']}".colorize(:light_blue)
      end
      snippets
    end

    def self.create_success(body)
      "Snippet \"#{body['title']}\" (#{body['file_name']} | #{body['id']}) successfully created: #{body['web_url']}".colorize(:green)
    end

    def self.update_success(body)
      "Snippet #{body['id']} successfully updated: #{body['web_url']}".colorize(:green)
    end

    def self.delete_success(id)
      "Snippet #{id} successfully deleted".colorize(:green)
    end
  end
end
