# frozen_string_literal: true

# Copyright 2019 Richard Davis
#
# This file is part of glsnip.
#
# glsnip is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# glsnip is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with glsnip.  If not, see <http://www.gnu.org/licenses/>.

require 'faraday'

module Glsnip
  ##
  # = Request
  # Author::    Richard Davis
  # Copyright:: Copyright 2019 Richard Davis
  # License::   GNU Public License 3
  #
  # Generic wrapper for requests to the GitLab API
  class Request
    BASE_URL = 'https://gitlab.com/api/v4'
    private_constant :BASE_URL

    TOKEN = ENV['GLSNIP_TOKEN']
    private_constant :TOKEN

    attr_reader :url, :params, :response

    def initialize(endpoint, params = {})
      @url = "#{BASE_URL}/#{endpoint}"
      @params = params
    end

    def send
      puts 'WARNING: Implemented in child classes.'
    end
  end
end
