# frozen_string_literal: true

# Copyright 2019 Richard Davis
#
# This file is part of glsnip.
#
# glsnip is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# glsnip is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with glsnip.  If not, see <http://www.gnu.org/licenses/>.

require 'glsnip/get_request'
require 'glsnip/post_request'
require 'glsnip/put_request'
require 'glsnip/delete_request'

module Glsnip
  ##
  # = Snippets
  # Author::    Richard Davis
  # Copyright:: Copyright 2019 Richard Davis
  # License::   GNU Public License 3
  #
  # Provides interactions with the GitLab Snippets API
  class Snippets
    ENDPOINT = 'snippets'
    private_constant :ENDPOINT

    def self.list
      req = Glsnip::GetRequest.new(ENDPOINT)
      req.send
    end

    def self.read(id)
      req = Glsnip::GetRequest.new(ENDPOINT + "/#{id}")
      req.send
    end

    def self.read_raw(id)
      req = Glsnip::GetRequest.new(ENDPOINT + "/#{id}/raw")
      req.send
    end

    def self.create(params = {})
      req = Glsnip::PostRequest.new(ENDPOINT, params)
      req.send
    end

    def self.update(id, params = {})
      req = Glsnip::PutRequest.new(ENDPOINT + "/#{id}", params)
      req.send
    end

    def self.delete(id)
      req = Glsnip::DeleteRequest.new(ENDPOINT + "/#{id}")
      req.send
    end
  end
end
